/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.stream.api;

import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStream;

/**
 * Data writted in {@link OutputStream} can be read with the {@link InputStream}.
 * @author Gael Lalire
 */
public interface IStreamAccessor {

    /**
     * @return an input stream
     * @throws IOException if error occurs
     */
    InputStream getInputStream() throws IOException;

    /**
     * If you call this method the previous stream will be erased.
     * @return an output stream
     * @throws IOException if error occurs
     */
    OutputStream getOutputStream() throws IOException;

    /**
     * The file replace older only when output stream is closed.
     * Temporary means that input stream return same data while
     * we are writing to output stream. Some implementation may
     * provides this capability with no temporary outputstream
     * @return an output stream
     * @throws IOException if error occurs
     */
    OutputStream getTemporaryOutputStream() throws IOException;

    /**
     * After calling this method the inputStream will throw
     * an {@link IOException}.
     */
    void delete();

    /**
     * @return true if the stream can be read
     */
    boolean exists();

}
