/**
 * Copyright 2009-2012 Bull S.A.S.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ow2.util.stream.impl.delegator;

import java.io.File;
import java.io.FileNotFoundException;
import java.io.FileOutputStream;
import java.io.IOException;

/**
 * @author Gael Lalire
 */
public class DelegatorOutputStream extends FileOutputStream {

    /**
     * Keep delegatorFileAccessor to avoid deletion of tmp file.
     */
    private DelegatorStreamAccessor delegatorFileAccessor;

    private File temporaryFile;

    public DelegatorOutputStream(final DelegatorStreamAccessor delegatorFileAccessor, final File file, final boolean temporary)
            throws FileNotFoundException {
        super(file);
        if (temporary) {
            this.temporaryFile = file;
        }
    }

    @Override
    public void flush() throws IOException {
        super.flush();
        if (temporaryFile == null) {
            delegatorFileAccessor.doWrite();
        }
    }

    @Override
    public void close() throws IOException {
        super.flush();
        super.close();
        if (temporaryFile != null) {
            delegatorFileAccessor.doWrite(temporaryFile);
        } else {
            delegatorFileAccessor.doWrite();
        }
    }

    @Override
    protected void finalize() {
        if (temporaryFile != null) {
            temporaryFile.delete();
        }
    }

}
